==> haskell-hls-stylish-haskell-plugin-1.0.1.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-stylish-haskell-plugin
version:              1.0.1.0
visibility:           public
id:                   hls-stylish-haskell-plugin-1.0.1.0-LA2iqLa2XLxJ8IbSo4dFot
key:                  hls-stylish-haskell-plugin-1.0.1.0-LA2iqLa2XLxJ8IbSo4dFot
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a8b41503557484dfff562edfba7cb7d9
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-1.0.1.0-LA2iqLa2XLxJ8IbSo4dFot
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 ghc-9.0.2
    ghc-boot-th-9.0.2 ghcide-1.6.0.0-GX2FM7cgeZC7UGpO1psp9Y
    hls-plugin-api-1.3.0.0-6RKMRZYap0lFFFTKcdBVil
    lsp-types-1.4.0.1-7ShjpHJkxmk27ZGEfLRsPn
    stylish-haskell-0.13.0.0-AS1kk0UsuhJAOwK2am8cIh text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-1.0.1.2-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-stylish-haskell-plugin
version:              1.0.1.2
visibility:           public
id:                   hls-stylish-haskell-plugin-1.0.1.2-Lti489XQa8JACrM8WHVcQ8
key:                  hls-stylish-haskell-plugin-1.0.1.2-Lti489XQa8JACrM8WHVcQ8
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b6cd8543d7844ebdd6f7dba06ab2be5b
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-1.0.1.2-Lti489XQa8JACrM8WHVcQ8
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 ghc-9.0.2
    ghc-boot-th-9.0.2 ghcide-1.9.0.0-5anMjFM4ZyOCgE2oZnbicj
    hls-plugin-api-1.6.0.0-86l50UAgfoN5lgHfQ9pROC
    lsp-types-1.6.0.0-AZCmARhTUPj15XME0WtdS5
    stylish-haskell-0.13.0.0-FTsQ9O6zTGZ4BmIYa2sALJ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
